==> piglot-0.5.0.tar.gz: piglot-0.5.0/piglot/solver/crate/solver.py <==
"""Module for CRATE solver."""
from typing import Dict, Type, Tuple, List
import os
import sys
import subprocess
from piglot.solver.input_file_solver import (
    InputDataGenerator,
    InputFileCase,
    InputData,
    InputFileSolver,
    OutputField,
)
from piglot.solver.crate.fields import HresFile
from piglot.utils.solver_utils import has_keyword


class CrateCase(InputFileCase):
    """Class for Crate cases."""

    def __init__(
        self,
        name: str,
        fields: Dict[str, OutputField],
        generator: InputDataGenerator,
        crate: str,
        python_interp: str = 'python3',
        microstructure_dir: str = '.',
    ) -> None:
        super().__init__(name, fields, generator)
        self.crate_bin = crate
        self.python_interp = python_interp
        self.microstructure_dir = microstructure_dir

    def _run_case(self, input_data: InputData, tmp_dir: str) -> bool:
        """Run the case for the given set of parameters.

        Parameters
        ----------
        input_data : InputData
            Input data for this problem.
        tmp_dir : str
            Temporary directory to run the problem.

        Returns
        -------
        bool
            Whether the case ran successfully or not.
        """
        if not os.path.isdir(self.microstructure_dir):
            raise ValueError(f"Microstructure directory '{self.microstructure_dir}' not found.")
        command = [
            self.python_interp,
            self.crate_bin,
            input_data.input_file,
            self.microstructure_dir,
        ]
        # Run the analysis
        process_result = subprocess.run(
            command,
            stdout=sys.stdout,
            stderr=sys.stderr,
            check=False,
        )
        if process_result.returncode != 0:
            return False
        # Check if simulation completed
        output_dir, _ = os.path.splitext(input_data.input_file)
        case_name = os.path.basename(output_dir)
        screen_file = os.path.join(output_dir, f'{case_name}.screen')
        return has_keyword(screen_file, "Program Completed")

    @classmethod
    def get_supported_fields(cls) -> Dict[str, Type[OutputField]]:
        """Get the supported fields for this input file type.

        Returns
        -------
        Dict[str, Type[OutputField]]
            Names and supported fields for this input file type.
        """
        return {
            'hresFile': HresFile,
        }

    @classmethod
    def _get_file_dependencies(cls, input_file: str) -> List[str]:
        """Get the dependencies for a single given input file.

        Parameters
        ----------
        input_file : str
            Input file to check for dependencies.

        Returns
        -------
        List[str]
            Substitution dependencies for this input file.
        """
        if not os.path.exists(input_file):
            raise ValueError(f'Input file "{input_file}" does not exist.')
        deps = []
        return deps

    @classmethod
    def get_dependencies(cls, input_file: str) -> Tuple[List[str], List[str]]:
        """Get the dependencies for a given input file.

        Parameters
        ----------
        input_file : str
            Input file to check for dependencies.

        Returns
        -------
        Tuple[List[str], List[str]]
            Substitution and copy dependencies for this input file.
        """
        if not os.path.exists(input_file):
            raise ValueError(f'Input file "{input_file}" does not exist.')
        # Start with the raw dependencies of the input file
        deps = cls._get_file_dependencies(input_file)
        return deps, []


class CrateSolver(InputFileSolver):
    """CRATE solver class."""

    @classmethod
    def get_case_class(cls) -> Type[InputFileCase]:
        """Get the case class to use for this solver.

        Returns
        -------
        Type[InputFileCase]
            InputFileCase class to use for this solver.
        """
        return CrateCase

==> piglot-0.5.1.tar.gz: piglot-0.5.1/piglot/solver/crate/solver.py <==
"""Module for CRATE solver."""
from typing import Dict, Type
import os
import sys
import subprocess
from piglot.solver.input_file_solver import (
    InputDataGenerator,
    InputFileCase,
    InputData,
    InputFileSolver,
    OutputField,
)
from piglot.solver.crate.fields import HresFile
from piglot.utils.solver_utils import has_keyword


class CrateCase(InputFileCase):
    """Class for Crate cases."""

    def __init__(
        self,
        name: str,
        fields: Dict[str, OutputField],
        generator: InputDataGenerator,
        crate: str,
        python_interp: str = 'python3',
        microstructure_dir: str = '.',
    ) -> None:
        super().__init__(name, fields, generator)
        self.crate_bin = crate
        self.python_interp = python_interp
        self.microstructure_dir = microstructure_dir

    def _run_case(self, input_data: InputData, tmp_dir: str) -> bool:
        """Run the case for the given set of parameters.

        Parameters
        ----------
        input_data : InputData
            Input data for this problem.
        tmp_dir : str
            Temporary directory to run the problem.

        Returns
        -------
        bool
            Whether the case ran successfully or not.
        """
        if not os.path.isdir(self.microstructure_dir):
            raise ValueError(f"Microstructure directory '{self.microstructure_dir}' not found.")
        command = [
            self.python_interp,
            self.crate_bin,
            input_data.input_file,
            os.path.abspath(self.microstructure_dir),
        ]
        # Run the analysis
        process_result = subprocess.run(
            command,
            stdout=sys.stdout,
            stderr=sys.stderr,
            check=False,
            cwd=tmp_dir,
        )
        if process_result.returncode != 0:
            return False
        # Check if simulation completed
        output_dir, _ = os.path.splitext(os.path.join(input_data.tmp_dir, input_data.input_file))
        case_name = os.path.basename(output_dir)
        screen_file = os.path.join(output_dir, f'{case_name}.screen')
        return has_keyword(screen_file, "Program Completed")

    @classmethod
    def get_supported_fields(cls) -> Dict[str, Type[OutputField]]:
        """Get the supported fields for this input file type.

        Returns
        -------
        Dict[str, Type[OutputField]]
            Names and supported fields for this input file type.
        """
        return {
            'hresFile': HresFile,
        }


class CrateSolver(InputFileSolver):
    """CRATE solver class."""

    @classmethod
    def get_case_class(cls) -> Type[InputFileCase]:
        """Get the case class to use for this solver.

        Returns
        -------
        Type[InputFileCase]
            InputFileCase class to use for this solver.
        """
        return CrateCase
